@@ -96,7 +96,7 @@ class DataNode:
         return False
 
 
-class LiteralNodeDataType(enum.Enum):
+class LiteralNodeDataType(str, enum.Enum):
     String = "string"
     Entity = "entity-id"
 
@@ -161,6 +161,15 @@ class SemanticModel:
 
     def get_n_edges(self):
         return len(self.g.edges)
+    
+    def in_degree(self, nid: str) -> int:
+        return self.g.in_degree(nid)
+    
+    def out_degree(self, nid: str) -> int:
+        return self.g.out_degree(nid)
+
+    def degree(self, nid: str) -> int:
+        return self.g.degree(nid)
 
     def get_node(self, nid: str) -> Optional[Node]:
         if nid not in self.g.nodes:
@@ -226,6 +235,9 @@ class SemanticModel:
 
     def remove_node(self, node_id: str):
         self.g.remove_node(node_id)
+    
+    def remove_edge(self, edge: Edge):
+        self.g.remove_edge(edge.source, edge.target, edge.id)
 
     def remove_edges_between_nodes(self, source_id: str, target_id: str, eid: Optional[str] = None):
         if eid is None:
@@ -293,7 +305,7 @@ class SemanticModel:
             f.write(orjson.dumps(self.to_dict(), option=orjson.OPT_INDENT_2))
 
     @staticmethod
-    def from_json(record: dict):
+    def from_dict(record: dict):
         sm = SemanticModel()
         for u in record['nodes']:
             if 'col_index' in u:
@@ -313,7 +325,7 @@ class SemanticModel:
     def from_json_file(infile: Union[str, Path]):
         with open(infile, "rb") as f:
             record = orjson.loads(f.read())
-            return SemanticModel.from_json(record)
+            return SemanticModel.from_dict(record)
 
     def draw(self, filename=None, no_display: bool = False, max_char_per_line: int = 20):
         """
@@ -530,10 +542,3 @@ class SemanticModel:
                 plt.show()
             finally:
                 fobj.close()
-
-
-if __name__ == '__main__':
-    record = grams.misc.deserialize_json("/workspace/sm-dev/grams/examples/ground-truth/table_01/version.01.json")[
-        'semantic_models'][0]
-    sm = SemanticModel.from_json(record)
-    print(list(sm.iter_nodes()))
